Pyscales
========

This module provides representations for musical notes and intervals in the
basic 12-note even tempered system that is typically used in western music. It
provides basic arithmetic and conversion to and from midi numbers.
